**To disassociate from an administrator account**

The following ``disassociate-from-administrator-account`` example disassociates the requesting account from its current administrator account. ::

    aws securityhub disassociate-from-administrator-account

This command produces no output.

For more information, see `Managing administrator and member accounts <https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-accounts.html>`__ in the *AWS Security Hub User Guide*.
